@@ -16,8 +16,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#define NL_MAJOR 1
-#define NL_MINOR 2
-#define NL_REV   7
-#define NL_DATE  "Sep 09, 2003"
-#define VERSION  "1.2.7"
+#define NL_MAJOR 2
+#define NL_MINOR 0
+#define NL_REV   9
+#define NL_DATE  "Mar 18, 2004"
+#define VERSION  "2.0.9"
